<?php
/**
 * The header for our theme
 *
 * @subpackage Digital Marketing Expert
 * @since 1.0
 * @version 0.1
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js no-svg">
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

<?php if ( function_exists( 'wp_body_open' ) ) {
    wp_body_open();
} else {
    do_action( 'wp_body_open' );
}?>

<a class="screen-reader-text skip-link" href="#skip-content"><?php esc_html_e( 'Skip to content', 'digital-marketing-expert' ); ?></a>

<div id="header">
	<div class="topbar py-2">
		<div class="container">
			<div class="row">
				<div class="col-lg-3 col-md-6 align-self-center">
					<div class="logo text-md-left text-center">
						<?php if ( has_custom_logo() ) : ?>
		            		<?php the_custom_logo(); ?>
			            <?php endif; ?>
		             	<?php if (get_theme_mod('digital_marketing_expert_show_site_title',true)) {?>
		          			<?php $blog_info = get_bloginfo( 'name' ); ?>
			                <?php if ( ! empty( $blog_info ) ) : ?>
			                  	<?php if ( is_front_page() && is_home() ) : ?>
			                    	<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
			                  	<?php else : ?>
		                      		<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
		                  		<?php endif; ?>
			                <?php endif; ?>
			            <?php }?>
			            <?php if (get_theme_mod('digital_marketing_expert_show_tagline',true)) {?>
			                <?php $description = get_bloginfo( 'description', 'display' );
		                  	if ( $description || is_customize_preview() ) : ?>
			                  	<p class="site-description"><?php echo esc_html($description); ?></p>
		              		<?php endif; ?>
		          		<?php }?>
					</div>
				</div>
				<div class="offset-lg-6 col-lg-3 col-md-6 align-self-center">
					<div class="social-icons text-md-right text-center">
						<?php if(get_theme_mod('digital_marketing_expert_facebook_url','')){ ?>
							<a href="<?php echo esc_url(get_theme_mod('digital_marketing_expert_facebook_url','')); ?>"><i class="fab fa-facebook-f"></i><span class="screen-reader-text"><?php echo esc_html('Facebook', 'digital-marketing-expert'); ?></span></a>
						<?php }?>
						<?php if(get_theme_mod('digital_marketing_expert_instagram_url','')){ ?>
							<a href="<?php echo esc_url(get_theme_mod('digital_marketing_expert_instagram_url','')); ?>"><i class="fab fa-instagram"></i><span class="screen-reader-text"><?php echo esc_html('Instagram', 'digital-marketing-expert'); ?></span></a>
						<?php }?>
						<?php if(get_theme_mod('digital_marketing_expert_twitter_url','')){ ?>
							<a href="<?php echo esc_url(get_theme_mod('digital_marketing_expert_twitter_url','')); ?>"><i class="fab fa-twitter"></i><span class="screen-reader-text"><?php echo esc_html('Twitter', 'digital-marketing-expert'); ?></span></a>
						<?php }?>
						<?php if(get_theme_mod('digital_marketing_expert_linkedin_url','')){ ?>
							<a href="<?php echo esc_url(get_theme_mod('digital_marketing_expert_linkedin_url','')); ?>"><i class="fab fa-linkedin-in"></i><span class="screen-reader-text"><?php echo esc_html('Youtube', 'digital-marketing-expert'); ?></span></a>
						<?php }?>
					</div>
				</div>
			</div>
		</div>
	</div>
	<div class="menu-section">
		<div class="container">
			<div class="row">
				<div class="col-lg-10 col-md-9 col-3 align-self-center">
					<div class="menu-bar">
						<div class="toggle-menu responsive-menu text-right">
							<?php if(has_nav_menu('primary')){ ?>
				            	<button onclick="digital_marketing_expert_open()" role="tab" class="mobile-menu"><i class="fas fa-bars"></i><span class="screen-reader-text"><?php esc_html_e('Open Menu','digital-marketing-expert'); ?></span></button>
				            <?php }?>
				        </div>
						<div id="sidelong-menu" class="nav sidenav">
			                <nav id="primary-site-navigation" class="nav-menu" role="navigation" aria-label="<?php esc_attr_e( 'Top Menu', 'digital-marketing-expert' ); ?>">
			                  	<?php if(has_nav_menu('primary')){
				                    wp_nav_menu( array( 
										'theme_location' => 'primary',
										'container_class' => 'main-menu-navigation clearfix' ,
										'menu_class' => 'clearfix',
										'items_wrap' => '<ul id="%1$s" class="%2$s mobile_nav">%3$s</ul>',
										'fallback_cb' => 'wp_page_menu',
				                    ) ); 
			                  	} ?>
			                  	<a href="javascript:void(0)" class="closebtn responsive-menu" onclick="digital_marketing_expert_close()"><i class="fas fa-times"></i><span class="screen-reader-text"><?php esc_html_e('Close Menu','digital-marketing-expert'); ?></span></a>
			                </nav>
			            </div>
			        </div>
				</div>
				<div class="col-lg-2 col-md-3 col-9 align-self-center contact-btn">
					<?php if (get_theme_mod('digital_marketing_expert_contact_btn_text') != '' || get_theme_mod('digital_marketing_expert_contact_btn_url') != '') {?>
						<a href="<?php echo esc_url(get_theme_mod('digital_marketing_expert_contact_btn_url')); ?>"><?php echo esc_html(get_theme_mod('digital_marketing_expert_contact_btn_text')); ?><span class="screen-reader-text"><?php echo esc_html(get_theme_mod('digital_marketing_expert_contact_btn_text')); ?></span></a>
					<?php }?>
				</div>
			</div>
		</div>
	</div>
</div>

<?php if(is_singular()) {?>
	<div id="inner-pages-header">
		<div class="hex center">
			<div class="hex odd first one"></div>
			<div class="hex odd first three"></div>
			<div class="hex odd first five"></div>
			<div class="hex odd first seven"></div>
			<div class="hex odd first nine"></div> 
			<div class="hex odd first eleven"></div>
		</div>
		<div class="header-overlay"></div>
	    <div class='header-content'> 
	    	<div class="row">
	    		<div class="col-lg-7 col-md-8 align-self-center">
			      	<h1><?php single_post_title(); ?></h1>
			      	<div class="theme-breadcrumb mt-3">
						<?php digital_marketing_expert_breadcrumb();?>
					</div>
	    		</div>
	    		<?php if(has_post_thumbnail()) {?>
		    		<div class="col-lg-5 col-md-4 align-self-center">
		    			<div class="sliderimg">
		        			<div class="slidehexaimg04">
		        				<div class="slidehexaimg03">
		        					<div class="slidehexaimg02">
		        						<div class="slidehexaimg">
				            				<?php the_post_thumbnail(); ?>
					            		</div>
					            	</div>
					            </div>
					        </div>
					    </div>
		    		</div>
		    	<?php }?>
	    	</div>
	    </div>
	</div>
<?php } ?>